@@ -15,8 +15,24 @@ PYNAMODB_TYPE_MAPPING = {
     attributes.NullAttribute: fields.Raw,
     attributes.UnicodeSetAttribute: custom_fields.UnicodeSet,
     attributes.NumberSetAttribute: custom_fields.NumberSet,
+    attributes.BinaryAttribute: custom_fields.Binary64Field,
 }
 
+try:
+    import pynamodb_attributes  # noqa
+    from marshmallow_enum import EnumField  # noqa
+
+    PYNAMODB_TYPE_MAPPING.update(
+        {
+            pynamodb_attributes.uuid.UUIDAttribute: fields.UUID,
+            pynamodb_attributes.integer.IntegerAttribute: fields.Integer,
+            pynamodb_attributes.unicode_enum.UnicodeEnumAttribute: EnumField,
+            pynamodb_attributes.integer_enum.IntegerEnumAttribute: EnumField,
+        }
+    )
+except ImportError:
+    pass
+
 
 def attribute2field(attribute):
     try:
